==> ejc-middlemeasurement-impl-3.0.0-20221201.064926-249-sources.jar: com/ejianc/business/middlemeasurement/vo/SubcontractingvolumeodetailVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包报量报告其他扣款子表
 * 
 * @author generator
 * 
 */
public class SubcontractingvolumeodetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.String sort; // 序号
    private java.lang.String expenseName; // 费用名称
    private java.lang.String unit; // 单位
    private java.math.BigDecimal oQuantity; // 数量
    private java.math.BigDecimal oUnitPrice; // 单价
    private java.math.BigDecimal amounts; // 金额
    private java.lang.String remarks; // 备注
    private java.lang.String errorMsg; // 错误信息
    private java.lang.String withholdingOther; //其他扣款/代扣款

    public String getWithholdingOther() {
        return withholdingOther;
    }

    public void setWithholdingOther(String withholdingOther) {
        this.withholdingOther = withholdingOther;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 费用名称
     */
    public java.lang.String getExpenseName() {
        return expenseName;
    }

    /**
     * 费用名称
     */
    public void setExpenseName(java.lang.String expenseName) {
        this.expenseName = expenseName;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }

    public BigDecimal getoQuantity() {
        return oQuantity;
    }

    public void setoQuantity(BigDecimal oQuantity) {
        this.oQuantity = oQuantity;
    }

    public BigDecimal getoUnitPrice() {
        return oUnitPrice;
    }

    public void setoUnitPrice(BigDecimal oUnitPrice) {
        this.oUnitPrice = oUnitPrice;
    }

    /**
     * 金额
     */
    public java.math.BigDecimal getAmounts() {
        return amounts;
    }

    /**
     * 金额
     */
    public void setAmounts(java.math.BigDecimal amounts) {
        this.amounts = amounts;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20221219.062630-293-sources.jar: com/ejianc/business/middlemeasurement/vo/SubcontractingvolumeodetailVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包报量报告其他扣款子表
 * 
 * @author generator
 * 
 */
public class SubcontractingvolumeodetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.String sort; // 序号
    private java.lang.String expenseName; // 费用名称
    private java.lang.String unit; // 单位
    private java.math.BigDecimal oQuantity; // 数量
    private java.math.BigDecimal oUnitPrice; // 单价
    private java.math.BigDecimal amounts; // 金额
    private java.lang.String remarks; // 备注
    private java.lang.String errorMsg; // 错误信息
    private java.lang.String withholdingOther; //其他扣款/代扣款
    private BigDecimal oUnitTaxPrice; //单价(含税)
    private BigDecimal taxAmounts; //金额(含税)

    public String getWithholdingOther() {
        return withholdingOther;
    }

    public void setWithholdingOther(String withholdingOther) {
        this.withholdingOther = withholdingOther;
    }

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 费用名称
     */
    public java.lang.String getExpenseName() {
        return expenseName;
    }

    /**
     * 费用名称
     */
    public void setExpenseName(java.lang.String expenseName) {
        this.expenseName = expenseName;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }

    public BigDecimal getoQuantity() {
        return oQuantity;
    }

    public void setoQuantity(BigDecimal oQuantity) {
        this.oQuantity = oQuantity;
    }

    public BigDecimal getoUnitPrice() {
        return oUnitPrice;
    }

    public void setoUnitPrice(BigDecimal oUnitPrice) {
        this.oUnitPrice = oUnitPrice;
    }

    /**
     * 金额
     */
    public java.math.BigDecimal getAmounts() {
        return amounts;
    }

    /**
     * 金额
     */
    public void setAmounts(java.math.BigDecimal amounts) {
        this.amounts = amounts;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public BigDecimal getoUnitTaxPrice() {
        return oUnitTaxPrice;
    }

    public void setoUnitTaxPrice(BigDecimal oUnitTaxPrice) {
        this.oUnitTaxPrice = oUnitTaxPrice;
    }

    public BigDecimal getTaxAmounts() {
        return taxAmounts;
    }

    public void setTaxAmounts(BigDecimal taxAmounts) {
        this.taxAmounts = taxAmounts;
    }
}
